"skewt.data" <-
structure(list(pseudox = structure(c(17.3051433922329, 17.2989428595704, 
17.2932651410438, 17.2880834542373, 17.2833694728839, 17.27909308, 
17.2752220849696, 17.2717218987219, 17.2685551600894, 17.2656813051477, 
17.2630560697911, 17.2606309139155, 17.2601199726826, 17.2588705584636, 
17.2579570357398, 17.2573676515475, 17.2570894675302, 17.2571080336316, 
17.2574069311649, 17.257980763743, 17.2588116279734, 17.2598810751258, 
17.2611698462193, 17.2626566065216, 17.2643176422483, 17.2661264884058, 
17.2680534959655, 17.2700653551824, 17.2721246033246, 17.2741891601946, 
17.2762119540590, 17.2781407240027, 17.2797124880103, 17.2839010078384, 
17.2858278854231, 17.2875337152432, 17.2889536137374, 17.2921990432659, 
17.2962825373800, 17.3007006135903, 17.3054121927579, 17.3103724161692, 
17.3155324364105, 17.3208391558221, 17.3262348826955, 17.3316568668493, 
17.3370366681995, 17.3422993053719, 17.3473621272974, 17.3521333499549, 
17.3565102036191, 17.3579295956207, 17.3604536930190, 17.3620550966234, 
17.3625579390551, 17.3617669764034, 17.3594652072220, 17.3554111502962, 
17.3493357227503, 17.3409386513135, 17.3298843422415, 17.3157971305447, 
17.2982558272625, 17.2767874837796, 17.2508602920805, 17.2198755350518, 
17.1831584860816, 17.1399481277563, 17.0893855147563, 17.0337249925873, 
16.9659888140480, 16.8790156664283, 16.7922115723015, 16.6875392957300, 
16.5674211050648, 16.4298252875925, 16.2724592924504, 16.0927448154399, 
15.8877957490636, 15.6533169503045, 15.3894248308104, 15.0877375091579, 
15.1909191507341, 15.1756646495406, 15.1608984632791, 15.1465783888996, 
15.1326593710743, 15.11909308, 15.1058274263395, 15.0928060026049, 
15.0799674382162, 15.0672446529462, 15.0545639903678, 15.0418442091140, 
15.0316246956967, 15.0199575792791, 15.0084266592549, 14.9970092899004, 
14.9856741837271, 14.9743897022645, 14.9631217360471, 14.9518334868048, 
14.9404851986335, 14.9290338323444, 14.9174326856718, 14.9056309634581, 
14.8935537211630, 14.8811224906170, 14.8683093832441, 14.8573904166947, 
14.8464961064276, 14.8355403010480, 14.8244251203961, 14.8163269666724, 
14.8058789634128, 14.7953037713498, 14.7845345152074, 14.7734994599598, 
14.7621216759159, 14.7503186658088, 14.7380019433749, 14.7250765495594, 
14.7114404889445, 14.6969840655754, 14.6815890944614, 14.6651279631310, 
14.6474625171705, 14.6284427451326, 14.6079052419024, 14.5856714357847, 
14.5615455733313, 14.5353124672213, 14.5067350261884, 14.4755516017815, 
14.4414732041785, 14.4008376352240, 14.3595682907867, 14.3143872139204, 
14.2648981998046, 14.2106671999869, 14.1512183543300, 14.0860296373996, 
14.0145281041074, 13.9398362488374, 13.8530652733609, 13.7577324841896, 
13.6530521249796, 13.5361717404851, 13.4122044511524, 13.2741294353365, 
13.1228578043336, 12.9571672961458, 12.775686025925, 12.5768688509936, 
12.3589788298644, 12.1200781992674, 11.8580329279306, 11.5705335935617, 
11.2551331483113, 10.9114822895579, 10.5357590479412, 10.1261949340361, 
9.6804955285966, 9.19638297076769, 13.0880229537128, 13.0615421561304, 
13.0354771012265, 13.0097621001706, 12.9843263284807, 12.95909308, 
12.9339789050716, 12.9088926119989, 12.8837341065491, 12.8583930389019, 
12.8327964049746, 12.8091386222659, 12.7840408436378, 12.7587980097695, 
12.7333589055291, 12.7076748064522, 12.6830261996590, 12.6592209711919, 
12.6355536918222, 12.6119768683373, 12.5884387309433, 12.5648827125563, 
12.541246885814, 12.5174633762442, 12.4934577766839, 12.4691485948879, 
12.4444467728590, 12.4192553222634, 12.3934691246877, 12.3669749476593, 
12.3426478534008, 12.3153950718135, 12.2872990335027, 12.2582511582012, 
12.2281357796585, 12.1968296145657, 12.1642011716881, 12.1301100916530, 
12.0944064071669, 12.0569297133327, 12.0175082384082, 11.9759578069681, 
11.9320806901175, 11.8856643412120, 11.836480020395, 11.7842813170090, 
11.7288025852325, 11.6697573146728, 11.6068364634235, 11.5397067854227, 
11.4680091857311, 11.3913571353633, 11.3093351702129, 11.2214974852618, 
11.1273666149686, 11.0264321638502, 10.91814951982, 10.8019384511339, 
10.6771814628895, 10.5420045401372, 10.3993608478061, 10.2448552829282, 
10.0789133449388, 9.90069110752482, 9.70928872545332, 9.50374736919887, 
9.28304756604942, 9.04610977147649, 8.7917979587073, 8.51892682615312, 
8.22627287660425, 7.9125891478822, 7.5766228354282, 7.21713453223199, 
6.83564767242616, 6.42725884919475, 5.99236058938253, 5.52991163072513, 
5.03891743604392, 4.51843067907725, 3.96754843088834, 3.38540679379677, 
10.9834286762011, 10.9473815342449, 10.9110314249112, 10.8742760070107, 
10.8370037664101, 10.79909308, 10.7607306214984, 10.7226019999327, 
10.6846237742039, 10.6467024584253, 10.6087338813722, 10.5706025885694, 
10.5321812863893, 10.4965447883931, 10.4588985963292, 10.4211233950226, 
10.3831600037907, 10.3449453631084, 10.3064122133637, 10.2674887537105, 
10.2280982916205, 10.1881588964041, 10.1475830722675, 10.1062774681261, 
10.0641426421020, 10.0210728980662, 9.97695620942346, 9.93167424125133, 
9.88510247565824, 9.83711043665693, 9.78756199995663, 9.73631576007275, 
9.68615045131143, 9.6317082777194, 9.57517534282687, 9.51637631931554, 
9.45512512991982, 9.39122422825892, 9.32446383580123, 9.25462113810175, 
9.18145944566893, 9.104727327215, 9.0241577254556, 8.93946706782088, 
8.85035438617344, 8.7565004606387, 8.6575670027097, 8.55319589175702, 
8.44300847696453, 8.32660495376139, 8.20210722300534, 8.07332531441636, 
7.93669040776117, 7.79006523558106, 7.63581044323856, 7.4724721170371, 
7.29949223720337, 7.11629016362788, 6.92226328948576, 6.71678812727141, 
6.49922195614516, 6.26890516068874, 6.02516437166583, 5.76731647489104, 
5.49467348406401, 5.20654818133938, 4.9022603244647, 4.5811431148963, 
4.24254953339864, 3.88585809432918, 3.51047756049188, 3.11585020539805, 
2.70447875527363, 2.2707123647247, 1.81632541948403, 1.34086951635333, 
0.843916121523552, 0.325052207643314, -0.21612385146258, -0.780005244618362, 
-1.36697755653373, -1.97741649353216, 8.8693198408773, 8.82362060225909, 
8.7778202837706, 8.7318545129958, 8.68564243136579, 8.63909308, 
8.59210501493707, 8.54456600062523, 8.49635278008452, 8.4473309196289, 
8.3973547259304, 8.34626723350831, 8.29717502093355, 8.24508566369272, 
8.19190607248017, 8.13590789945266, 8.07886487223, 8.02101288143116, 
7.96226257825346, 7.90251968473725, 7.84168478320765, 7.77965310870992, 
7.71631435057434, 7.65155246554546, 7.58524550138339, 7.51726542607508, 
7.44747795371448, 7.37574235384074, 7.3019112268378, 7.22583022427214, 
7.14733769025231, 7.06626419855796, 6.98243196096606, 6.89565408539856, 
6.80573366865185, 6.71246271777396, 6.61562090662483, 6.5149741894634, 
6.41027331087583, 6.30125226994055, 6.18762681482522, 6.06909306036851, 
5.94532633381016, 5.815980360912, 5.68068690469817, 5.53905596079303, 
5.39130692049396, 5.23654567807787, 5.07455277730511, 4.90494850891334, 
4.72734317655766, 4.54133809473316, 4.34652679046918, 4.14249642343462, 
3.92882943511941, 3.70510543067685, 3.47090328625409, 3.22580345997613, 
2.96939046654665, 2.70125545471351, 2.42099880536593, 2.12823264813775, 
1.8225831788211, 1.50369265142676, 1.17122091980478, 0.824846416106464, 
0.464266477792906, 0.0891969710428775, -0.300628795139314, -0.705461815413283, 
-1.12553968719240, -1.56108929371912, -2.01232964455361, -2.47947459611463, 
-2.95872612684821, -3.45796943963609, -3.97377226888853, -4.50634809323703, 
-5.05590564375613, -5.62264474479052, -6.20675065628543, -6.80838728764349, 
6.77831772704848, 6.71948788078446, 6.66024960367034, 6.60050919906525, 
6.54016217588293, 6.47909308, 6.41717542011243, 6.35427168908186, 
6.29023348126375, 6.2249017058425, 6.15810689579234, 6.09259502234998, 
6.02413044737311, 5.95428257377271, 5.88295400057493, 5.810041246535, 
5.73543447907136, 5.65901725952678, 5.58066631063983, 5.5002513120674, 
5.41763472952653, 5.33267168260209, 5.24520985550712, 5.15508945410501, 
5.06214321134919, 4.96544321943421, 4.86447279455346, 4.76074565208796, 
4.65409498138669, 4.54434615291771, 4.43131619983376, 4.31484476475966, 
4.19469068292192, 4.07063572609886, 3.94245971418652, 3.80993234989983, 
3.67281307398837, 3.53085107678464, 3.38378550162564, 3.23134587268157, 
3.07325277410780, 2.90921879920850, 2.74088005762418, 2.56501257906871, 
2.38256986542532, 2.19327978408104, 1.99686852200273, 1.79306162179306, 
1.58158509583726, 1.36216660565135, 1.13453668897216, 0.898430012186143, 
0.653586620623024, 0.399753154372238, 0.136683993046701, -0.135857710202, 
-0.418099146605096, -0.710257162212523, -1.01253779831214, -1.32513609343277, 
-1.64823616981836, -1.98201161580829, -2.32662616166401, -2.68223463052745, 
-3.04898412899665, -3.42701542400324, -3.81646443510701, -4.21746375492128, 
-4.6301440962099, -5.05463555349456, -5.49106856128268, -5.93957443207948, 
-6.40028536730572, -6.87333385543792, -7.35885140632547, -7.856966620241, 
-8.3678026546993, -8.8914742285377, -9.42808438413466, -9.97772130258074, 
-10.5404555149944, -11.1163378530414, 4.69967599684703, 4.62557547853907, 
4.55058643310393, 4.47459399843423, 4.39747398229793, 4.31909307999999, 
4.23930918045812, 4.15797175933475, 4.07492235703379, 3.98999513851152, 
3.90301753097215, 3.81687497267339, 3.72710472431085, 3.63536874386069, 
3.54157060244478, 3.44560941169168, 3.34737967576727, 3.24677114889118, 
3.14366869974693, 3.03795218446032, 2.92949633021732, 2.81817063212923, 
2.70383926663402, 2.58636102553892, 2.46558927572689, 2.34137195052574, 
2.21355157970275, 2.08196536591335, 1.94644531610187, 1.80681843671502, 
1.66290700154024, 1.51452890041571, 1.36149807590905, 1.20362505326797, 
1.04071756650901, 0.872581280463646, 0.699020605034008, 0.519839593958682, 
0.334842916236961, 0.146049710655252, -0.0506477422751042, -0.255320558896862, 
-0.466259553862647, -0.683496843759201, -0.907205916279217, -1.13755629651005, 
-1.37471293173180, -1.61883562984477, -1.87007856580488, -2.12858987084959, 
-2.39451131893324, -2.66797812363419, -2.94911885682591, -3.23805549763171, 
-3.5349036166334, -3.83977269605942, -4.15276658182789, -4.47398405800764, 
-4.80351952863908, -5.14146378610905, -5.48790483959868, -5.84292877173785, 
-6.20662058674554, -6.57906500928965, -6.96034719038448, -7.35055327524688, 
-7.74977078860971, -8.15808335523754, -8.57558359150481, -9.00236645792674, 
-9.43852404064522, -9.88414784605981, -10.3393275743270, -10.8041496880084, 
-11.2786958570621, -11.7630413856587, -12.2572537437646, -12.7613913312339, 
-13.2755025876899, -13.7996255211296, -14.3337876563495, -14.8780062972731
), .Dim = c(82, 7)), pseudoy = structure(c(-0.934621706320542, 
-0.751505962843567, -0.566620957734585, -0.379932168001829, -0.191404050236997, 
-0.00100000000000477, 0.191317690837366, 0.385587878912986, 0.58185061649499, 
0.780147201043576, 0.98052022736806, 1.18301364254367, 1.38767280376507, 
1.59454453932747, 1.8036772129403, 2.01512079159389, 2.2289269172185, 
2.44514898239143, 2.66384221037106, 2.88506373975716, 3.10887271410252, 
3.33533037682741, 3.56450017181783, 3.79644785012107, 4.03124158318781, 
4.26895208314798, 4.50965273065185, 4.75341971085473, 5.00033215817528, 
5.25047231051605, 5.5039256736983, 5.76078119693346, 6.0211314602326, 
6.28507287474189, 6.55270589708883, 6.82413525893183, 7.09947021302581, 
7.37882479725053, 7.6623181181989, 7.95007465608973, 8.24222459295915, 
8.53890416629596, 8.84025605052572, 9.14642976901742, 9.4575821395906, 
9.77387775684628, 10.0954895150355, 10.4225991756234, 10.7553979842143, 
11.0940873420798, 11.4388795381941, 11.7899985484402, 12.1476809095196, 
12.5121766761071, 12.8837504709488, 13.2626826389507, 13.6492705178637, 
14.0438298399942, 14.4466962814944, 14.8582271782782, 15.2788034305446, 
15.7088316213421, 16.1487463787078, 16.5990130157781, 17.0601304890717, 
17.5326347220986, 18.0171023498054, 18.5141549494667, 19.0244638358841, 
19.5487555136925, 20.0878178978825, 20.6425074362012, 21.2137572950404, 
21.8025868052466, 22.4101124079681, 23.0375603957970, 23.6862818145741, 
24.3577699810305, 25.0536811873909, 25.7758593150578, 26.5263652779014, 
27.3075124789449, -0.934621706320542, -0.751505962843567, -0.566620957734585, 
-0.379932168001829, -0.191404050236997, -0.00100000000000477, 
0.191317690837366, 0.385587878912986, 0.58185061649499, 0.780147201043576, 
0.98052022736806, 1.18301364254367, 1.38767280376507, 1.59454453932747, 
1.8036772129403, 2.01512079159389, 2.2289269172185, 2.44514898239143, 
2.66384221037106, 2.88506373975716, 3.10887271410252, 3.33533037682741, 
3.56450017181783, 3.79644785012107, 4.03124158318781, 4.26895208314798, 
4.50965273065185, 4.75341971085473, 5.00033215817528, 5.25047231051605, 
5.5039256736983, 5.76078119693346, 6.0211314602326, 6.28507287474189, 
6.55270589708883, 6.82413525893183, 7.09947021302581, 7.37882479725053, 
7.6623181181989, 7.95007465608973, 8.24222459295915, 8.53890416629596, 
8.84025605052572, 9.14642976901742, 9.4575821395906, 9.77387775684628, 
10.0954895150355, 10.4225991756234, 10.7553979842143, 11.0940873420798, 
11.4388795381941, 11.7899985484402, 12.1476809095196, 12.5121766761071, 
12.8837504709488, 13.2626826389507, 13.6492705178637, 14.0438298399942, 
14.4466962814944, 14.8582271782782, 15.2788034305446, 15.7088316213421, 
16.1487463787078, 16.5990130157781, 17.0601304890717, 17.5326347220986, 
18.0171023498054, 18.5141549494667, 19.0244638358841, 19.5487555136925, 
20.0878178978825, 20.6425074362012, 21.2137572950404, 21.8025868052466, 
22.4101124079681, 23.0375603957970, 23.6862818145741, 24.3577699810305, 
25.0536811873909, 25.7758593150578, 26.5263652779014, 27.3075124789449, 
-0.934621706320542, -0.751505962843567, -0.566620957734585, -0.379932168001829, 
-0.191404050236997, -0.00100000000000477, 0.191317690837366, 
0.385587878912986, 0.58185061649499, 0.780147201043576, 0.98052022736806, 
1.18301364254367, 1.38767280376507, 1.59454453932747, 1.8036772129403, 
2.01512079159389, 2.2289269172185, 2.44514898239143, 2.66384221037106, 
2.88506373975716, 3.10887271410252, 3.33533037682741, 3.56450017181783, 
3.79644785012107, 4.03124158318781, 4.26895208314798, 4.50965273065185, 
4.75341971085473, 5.00033215817528, 5.25047231051605, 5.5039256736983, 
5.76078119693346, 6.0211314602326, 6.28507287474189, 6.55270589708883, 
6.82413525893183, 7.09947021302581, 7.37882479725053, 7.6623181181989, 
7.95007465608973, 8.24222459295915, 8.53890416629596, 8.84025605052572, 
9.14642976901742, 9.4575821395906, 9.77387775684628, 10.0954895150355, 
10.4225991756234, 10.7553979842143, 11.0940873420798, 11.4388795381941, 
11.7899985484402, 12.1476809095196, 12.5121766761071, 12.8837504709488, 
13.2626826389507, 13.6492705178637, 14.0438298399942, 14.4466962814944, 
14.8582271782782, 15.2788034305446, 15.7088316213421, 16.1487463787078, 
16.5990130157781, 17.0601304890717, 17.5326347220986, 18.0171023498054, 
18.5141549494667, 19.0244638358841, 19.5487555136925, 20.0878178978825, 
20.6425074362012, 21.2137572950404, 21.8025868052466, 22.4101124079681, 
23.0375603957970, 23.6862818145741, 24.3577699810305, 25.0536811873909, 
25.7758593150578, 26.5263652779014, 27.3075124789449, -0.934621706320542, 
-0.751505962843567, -0.566620957734585, -0.379932168001829, -0.191404050236997, 
-0.00100000000000477, 0.191317690837366, 0.385587878912986, 0.58185061649499, 
0.780147201043576, 0.98052022736806, 1.18301364254367, 1.38767280376507, 
1.59454453932747, 1.8036772129403, 2.01512079159389, 2.2289269172185, 
2.44514898239143, 2.66384221037106, 2.88506373975716, 3.10887271410252, 
3.33533037682741, 3.56450017181783, 3.79644785012107, 4.03124158318781, 
4.26895208314798, 4.50965273065185, 4.75341971085473, 5.00033215817528, 
5.25047231051605, 5.5039256736983, 5.76078119693346, 6.0211314602326, 
6.28507287474189, 6.55270589708883, 6.82413525893183, 7.09947021302581, 
7.37882479725053, 7.6623181181989, 7.95007465608973, 8.24222459295915, 
8.53890416629596, 8.84025605052572, 9.14642976901742, 9.4575821395906, 
9.77387775684628, 10.0954895150355, 10.4225991756234, 10.7553979842143, 
11.0940873420798, 11.4388795381941, 11.7899985484402, 12.1476809095196, 
12.5121766761071, 12.8837504709488, 13.2626826389507, 13.6492705178637, 
14.0438298399942, 14.4466962814944, 14.8582271782782, 15.2788034305446, 
15.7088316213421, 16.1487463787078, 16.5990130157781, 17.0601304890717, 
17.5326347220986, 18.0171023498054, 18.5141549494667, 19.0244638358841, 
19.5487555136925, 20.0878178978825, 20.6425074362012, 21.2137572950404, 
21.8025868052466, 22.4101124079681, 23.0375603957970, 23.6862818145741, 
24.3577699810305, 25.0536811873909, 25.7758593150578, 26.5263652779014, 
27.3075124789449, -0.934621706320542, -0.751505962843567, -0.566620957734585, 
-0.379932168001829, -0.191404050236997, -0.00100000000000477, 
0.191317690837366, 0.385587878912986, 0.58185061649499, 0.780147201043576, 
0.98052022736806, 1.18301364254367, 1.38767280376507, 1.59454453932747, 
1.8036772129403, 2.01512079159389, 2.2289269172185, 2.44514898239143, 
2.66384221037106, 2.88506373975716, 3.10887271410252, 3.33533037682741, 
3.56450017181783, 3.79644785012107, 4.03124158318781, 4.26895208314798, 
4.50965273065185, 4.75341971085473, 5.00033215817528, 5.25047231051605, 
5.5039256736983, 5.76078119693346, 6.0211314602326, 6.28507287474189, 
6.55270589708883, 6.82413525893183, 7.09947021302581, 7.37882479725053, 
7.6623181181989, 7.95007465608973, 8.24222459295915, 8.53890416629596, 
8.84025605052572, 9.14642976901742, 9.4575821395906, 9.77387775684628, 
10.0954895150355, 10.4225991756234, 10.7553979842143, 11.0940873420798, 
11.4388795381941, 11.7899985484402, 12.1476809095196, 12.5121766761071, 
12.8837504709488, 13.2626826389507, 13.6492705178637, 14.0438298399942, 
14.4466962814944, 14.8582271782782, 15.2788034305446, 15.7088316213421, 
16.1487463787078, 16.5990130157781, 17.0601304890717, 17.5326347220986, 
18.0171023498054, 18.5141549494667, 19.0244638358841, 19.5487555136925, 
20.0878178978825, 20.6425074362012, 21.2137572950404, 21.8025868052466, 
22.4101124079681, 23.0375603957970, 23.6862818145741, 24.3577699810305, 
25.0536811873909, 25.7758593150578, 26.5263652779014, 27.3075124789449, 
-0.934621706320542, -0.751505962843567, -0.566620957734585, -0.379932168001829, 
-0.191404050236997, -0.00100000000000477, 0.191317690837366, 
0.385587878912986, 0.58185061649499, 0.780147201043576, 0.98052022736806, 
1.18301364254367, 1.38767280376507, 1.59454453932747, 1.8036772129403, 
2.01512079159389, 2.2289269172185, 2.44514898239143, 2.66384221037106, 
2.88506373975716, 3.10887271410252, 3.33533037682741, 3.56450017181783, 
3.79644785012107, 4.03124158318781, 4.26895208314798, 4.50965273065185, 
4.75341971085473, 5.00033215817528, 5.25047231051605, 5.5039256736983, 
5.76078119693346, 6.0211314602326, 6.28507287474189, 6.55270589708883, 
6.82413525893183, 7.09947021302581, 7.37882479725053, 7.6623181181989, 
7.95007465608973, 8.24222459295915, 8.53890416629596, 8.84025605052572, 
9.14642976901742, 9.4575821395906, 9.77387775684628, 10.0954895150355, 
10.4225991756234, 10.7553979842143, 11.0940873420798, 11.4388795381941, 
11.7899985484402, 12.1476809095196, 12.5121766761071, 12.8837504709488, 
13.2626826389507, 13.6492705178637, 14.0438298399942, 14.4466962814944, 
14.8582271782782, 15.2788034305446, 15.7088316213421, 16.1487463787078, 
16.5990130157781, 17.0601304890717, 17.5326347220986, 18.0171023498054, 
18.5141549494667, 19.0244638358841, 19.5487555136925, 20.0878178978825, 
20.6425074362012, 21.2137572950404, 21.8025868052466, 22.4101124079681, 
23.0375603957970, 23.6862818145741, 24.3577699810305, 25.0536811873909, 
25.7758593150578, 26.5263652779014, 27.3075124789449, -0.934621706320542, 
-0.751505962843567, -0.566620957734585, -0.379932168001829, -0.191404050236997, 
-0.00100000000000477, 0.191317690837366, 0.385587878912986, 0.58185061649499, 
0.780147201043576, 0.98052022736806, 1.18301364254367, 1.38767280376507, 
1.59454453932747, 1.8036772129403, 2.01512079159389, 2.2289269172185, 
2.44514898239143, 2.66384221037106, 2.88506373975716, 3.10887271410252, 
3.33533037682741, 3.56450017181783, 3.79644785012107, 4.03124158318781, 
4.26895208314798, 4.50965273065185, 4.75341971085473, 5.00033215817528, 
5.25047231051605, 5.5039256736983, 5.76078119693346, 6.0211314602326, 
6.28507287474189, 6.55270589708883, 6.82413525893183, 7.09947021302581, 
7.37882479725053, 7.6623181181989, 7.95007465608973, 8.24222459295915, 
8.53890416629596, 8.84025605052572, 9.14642976901742, 9.4575821395906, 
9.77387775684628, 10.0954895150355, 10.4225991756234, 10.7553979842143, 
11.0940873420798, 11.4388795381941, 11.7899985484402, 12.1476809095196, 
12.5121766761071, 12.8837504709488, 13.2626826389507, 13.6492705178637, 
14.0438298399942, 14.4466962814944, 14.8582271782782, 15.2788034305446, 
15.7088316213421, 16.1487463787078, 16.5990130157781, 17.0601304890717, 
17.5326347220986, 18.0171023498054, 18.5141549494667, 19.0244638358841, 
19.5487555136925, 20.0878178978825, 20.6425074362012, 21.2137572950404, 
21.8025868052466, 22.4101124079681, 23.0375603957970, 23.6862818145741, 
24.3577699810305, 25.0536811873909, 25.7758593150578, 26.5263652779014, 
27.3075124789449), .Dim = c(82, 7)), pseudo = c(32, 28, 24, 20, 
16, 12, 8), NPSEUDO = 7, plt = c(0.184615384615385, 0.881318681318681, 
0.168131868131868, 0.864835164835165)), .Names = c("pseudox", 
"pseudoy", "pseudo", "NPSEUDO", "plt"))
